#*******************************************************************************
# ALMA - Atacama Large Millimeter Array
# Copyright (c) ESO - European Southern Observatory, 2011
# (in the framework of the ALMA collaboration).
# All rights reserved.
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
#*******************************************************************************
# Holography Standard Script
# $Id: TowerHolographyScript.py 212670 2014-12-17 01:58:56Z nphillip $
#

from CCL.Global import *
from Observation.TowerHolographyTarget import TowerHolographyTarget
from CCL.logging import getLogger
from math import radians
import Control


array = getArray()
array.beginExecution()
if len(array.antennas()) != 1:
   # Throw something here
   logger = getLogger()
   logger.logCritical('Incorrect number of antennas in Holography Array')
   raise Exception("Incorrect number of antennas in Holography Array")

thOM = array.getTowerHolographyObservingMode()
schedBlk =  getSB()

towerObservation = \
          TowerHolographyTarget(schedBlk.HolographyParameters[0], thOM)

towerObservation.initializeHardware()
towerObservation.execute()
towerObservation.shutdownHardware()
array.endExecution(Control.SUCCESS, 'holography test end')

